#!/usr/bin/python3

import sys
import os

usageMessage = """

A script for generating a simple list of the correct answers from a
latex document meant for the main script LatexMCGeneratorDE, i.e.,
using Question and Answer environments. The output is a document meant
for publishing to students after MC exams in Digital Exam, which (June
2023) only allows students to see their answers, not their score nor
the correct answers.

Usage: createAnswerList file.tex

"""

# The code is essentially an excerpt of parts of the code in
# LatexMCGeneratorDE (plus some simplification and modification).
# 

def printSingleAnswerQuestion(Q,correctNum):
    Qtext = f"Spørgsmål {Q}:"
    Atext = f" svar {correctNum}"
    print(Qtext.ljust(16) + Atext)

def printMatrixQuestion(Q,aNums,correctNums):
    for A in aNums:
        Qtext = f"Spørgsmål {Q}.{A}:"
        Atext = f" svar {'1' if (A in correctNums) else '2'}"
        print(Qtext.ljust(16) + Atext)

# The stuff below is the main (modified) excerpt from LatexMCGenerator.

if len(sys.argv) < 2:
    print(usageMessage)
    sys.exit()
    
inputfilename = sys.argv[1]

# input file as a string:
input = open(sys.argv[1],'r').read()

# get rid of any old questions parked below "\end{document}"
input = input.split(r"\end{document}")[0]

# chop input at beginnings of Question and Answer environments, giving
# a list with an entry for each question, the entry being a list of
# the question and its answers.
cuts = [q.split(r"\begin{Answer") for q in input.split(r"\begin{Question")[1:]]

qcounter = 1
acounter = 1
for qpartslist in cuts:
    acounter = 1
    aNums = []
    correctNums = []
    for a in qpartslist[1:]:
        aNums.append(acounter)
        if a.startswith("T"):
            correctNums.append(acounter)
        acounter = acounter+1
    if len(correctNums) >= 2:
        printMatrixQuestion(qcounter,aNums,correctNums)
    else:
        correctNum = correctNums[0]
        printSingleAnswerQuestion(qcounter,correctNum)
    qcounter = qcounter+1
